==> nextcloud-25.0.6.tgz: nextcloud/apps/user_status/l10n/sr.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Скорашњи статуси",
    "In a meeting" : "На састанку",
    "Commuting" : "На путу до посла",
    "Out sick" : "На боловању",
    "Vacationing" : "На одмору",
    "Working remotely" : "Радим од куће",
    "In a call" : "У позиву",
    "User status" : "Корисников статус",
    "View profile" : "Погледај профил",
    "Clear status after" : "Обриши статус након",
    "What is your status?" : "Који је ваш статус?",
    "Set status" : "Постави статус",
    "Online status" : "Мрежни статус",
    "Status message" : "Порука стања",
    "Clear status message" : "Обриши статусну поруку",
    "Set status message" : "Постављање статусне поруке",
    "There was an error saving the status" : "Дошло је до грешке приликом чувања статуса",
    "There was an error clearing the status" : "Дошло је до грешке приликом брисања статуса",
    "No recent status changes" : "Нема скорашњих измена статуса",
    "Away" : "Одсутан",
    "Do not disturb" : "Не узнемиравај",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Не бриши",
    "Today" : "Данас",
    "This week" : "Ове недеље",
    "Online" : "На мрежи",
    "Invisible" : "Невидљива",
    "Offline" : "Ван мреже",
    "There was an error saving the new status" : "Дошло је до грешке приликом чувања новог статуса",
    "30 minutes" : "30 минута",
    "1 hour" : "1 сат",
    "4 hours" : "4 сата",
    "Mute all notifications" : "Искључи сва обавештења",
    "Appear offline" : "Прикажи као ван мреже",
    "Clear status message after" : "Обриши статусну поруку након"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-25.0.7.tgz: nextcloud/apps/user_status/l10n/sr.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Скорашњи статуси",
    "In a meeting" : "На састанку",
    "Commuting" : "На путу до посла",
    "Out sick" : "На боловању",
    "Vacationing" : "На одмору",
    "Working remotely" : "Радим од куће",
    "In a call" : "У позиву",
    "User status" : "Корисников статус",
    "View profile" : "Погледај профил",
    "Clear status after" : "Обриши статус након",
    "Emoji for your status message" : "Емођи за вашу статусну поруку",
    "What is your status?" : "Који је ваш статус?",
    "Predefined statuses" : "Предефинисани статуси",
    "Previously set" : "Претходно постављено",
    "Reset status" : "Ресетуј статус",
    "Set status" : "Постави статус",
    "Online status" : "Мрежни статус",
    "Status message" : "Порука стања",
    "Your status was set automatically" : "Ваш статус је аутоматски постављен",
    "Clear status message" : "Обриши статусну поруку",
    "Set status message" : "Постављање статусне поруке",
    "Reset status to \"{icon} {message}\"" : "Ресетуј статус на „{icon} {message}”",
    "Reset status to \"{message}\"" : "Ресетуј статус на „{message}”",
    "Reset status to \"{icon}\"" : "Ресетуј статус на „{icon}”",
    "There was an error saving the status" : "Дошло је до грешке приликом чувања статуса",
    "There was an error clearing the status" : "Дошло је до грешке приликом брисања статуса",
    "There was an error reverting the status" : "Дошло је до грешке приликом враћања претходног статуса",
    "No recent status changes" : "Нема скорашњих измена статуса",
    "Away" : "Одсутан",
    "Do not disturb" : "Не узнемиравај",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Не бриши",
    "Today" : "Данас",
    "This week" : "Ове недеље",
    "Online" : "На мрежи",
    "Invisible" : "Невидљива",
    "Offline" : "Ван мреже",
    "There was an error saving the new status" : "Дошло је до грешке приликом чувања новог статуса",
    "30 minutes" : "30 минута",
    "1 hour" : "1 сат",
    "4 hours" : "4 сата",
    "Mute all notifications" : "Искључи сва обавештења",
    "Appear offline" : "Прикажи као ван мреже",
    "Clear status message after" : "Обриши статусну поруку након"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
